@@ -229,11 +229,15 @@ OC.L10N.register(
     "Creating file" : "Создание файла",
     "Save as {displayName}" : "Сохранить как {displayName}",
     "Save as …" : "Сохранить как…",
+    "Converting files …" : "Преобразование файлов…",
     "Failed to convert files: {message}" : "Не удалось преобразовать файлы: {message}",
     "All files failed to be converted" : "Не удалось преобразовать все файлы",
     "One file could not be converted: {message}" : "Один файл не удалось преобразовать: {message}",
+    "_One file could not be converted_::_%n files could not be converted_" : ["Файл не удалось преобразовать","%n файлы не могут быть преобразованы","%n файлы не могут быть преобразованы","%n файлы не могут быть преобразованы"],
+    "_One file successfully converted_::_%n files successfully converted_" : ["Файл успешно преобразован","%n файлы успешно преобразованы","%n файлы успешно преобразованы","%n файлы успешно преобразованы"],
     "Files successfully converted" : "Файлы успешно конвертированы",
     "Failed to convert files" : "Не удалось преобразовать файлы",
+    "Converting file …" : "Преобразование файла…",
     "File successfully converted" : "Файл успешно преобразован",
     "Failed to convert file: {message}" : "Не удалось преобразовать файл: {message}",
     "Failed to convert file" : "Не удалось преобразовать файл",
@@ -276,6 +280,7 @@ OC.L10N.register(
     "Open file locally" : "Открыть файл локально",
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Теперь файл должен открыться на вашем устройстве. Если это не произошло, пожалуйста, убедитесь, что у вас установлено настольное приложение.",
     "Retry and close" : "Повторить попытку и закрыть",
+    "Open online" : "Открыть онлайн",
     "Failed to redirect to client" : "Ошибка перенаправления в клиент",
     "Open locally" : "Открыть локально",
     "Rename" : "Переименовать",
@@ -429,6 +434,7 @@ OC.L10N.register(
     "Upload file" : "Загрузить файл",
     "Not favorited" : "Не избранное",
     "An error occurred while trying to update the tags" : "Во время обновления тегов возникла ошибка",
+    "You don't have permission to upload or create files here." : "У вас нет разрешения на загрузку или создание файлов здесь.",
     "Storage informations" : "Сведения о хранилище",
     "Choose file" : "Выберите файл",
     "Go to the previous folder" : "Перейти к предыдущей папке",
