@@ -80,6 +80,7 @@ OC.L10N.register(
     "Go to the \"{dir}\" directory" : "Ísť do \"{dir}\" adresára",
     "Current directory path" : "Aktuálna cesta k adresáru",
     "Your have used your space quota and cannot upload files anymore" : "Dosiahli ste limit vášho priestoru a už viac nemôžete nahrávať súbory",
+    "You do not have permission to upload or create files here." : "Nemáte oprávnenie sem nahrávať alebo vytvárať súbory.",
     "Drag and drop files here to upload" : "Pre nahratie presuňte do tohto priestoru súbory ťahaním",
     "Favorite" : "Obľúbené",
     "Back" : "Späť",
@@ -105,6 +106,7 @@ OC.L10N.register(
     "Toggle selection for all files and folders" : "Prepnúť výber pre všetky súbory a adresáre",
     "Name" : "Názov",
     "Size" : "Veľkosť",
+    "\"{displayName}\" failed on some elements" : "\"{displayName}\" zlyhalo na niektorých prvkoch.",
     "\"{displayName}\" batch action executed successfully" : "Hromadná operácia \"{displayName}\" bola úspešne vykonaná",
     "\"{displayName}\" action failed" : "\"{displayName}\" akcia zlýhala",
     "Actions" : "Akcie",
@@ -127,6 +129,7 @@ OC.L10N.register(
     "This name is already in use." : "Toto meno je už používané.",
     "Create" : "Vytvoriť",
     "Fill template fields" : "Vyplňte položky šablóny",
+    "Submitting fields …" : "Položky sa odosielajú ...",
     "Submit" : "Odoslať",
     "Choose a file or folder to transfer" : "Vyberte súbor alebo priečinok na prevod",
     "Transfer" : "Prevod",
@@ -139,11 +142,15 @@ OC.L10N.register(
     "Choose file or folder to transfer" : "Vyberte súbor alebo priečinok na prevod",
     "Change" : "Zmeniť",
     "New owner" : "Nový vlastník",
+    "Keep {old}" : "Ponechať {old}",
+    "Keep without extension" : "Ponechať bez prípony",
+    "Use {new}" : "Použiť {new}",
     "Remove extension" : "Odstrániť príponu",
     "Change file extension" : "Zmeniť príponu súboru",
     "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Zmena prípony súboru z „{old}“ na „{new}“ môže spôsobiť, že súbor bude nečitateľný.",
     "Removing the file extension \"{old}\" may render the file unreadable." : "Odstránenie prípony súboru „{old}“ môže spôsobiť, že súbor bude nečitateľný.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "Pridanie prípony súboru „{new}“ môže spôsobiť, že súbor bude nečitateľný.",
+    "Do not show this dialog again." : "Toto dialógové okno už nezobrazovať.",
     "Select file or folder to link to" : "Vyberte súbor alebo priečinok na ktorý odkazovať",
     "Choose {file}" : "Vyberte {file}",
     "Share" : "Zdieľať",
@@ -164,6 +171,7 @@ OC.L10N.register(
     "No files in here" : "Nie sú tu žiadne súbory",
     "Upload some content or sync with your devices!" : "Nahrajte nejaký obsah alebo synchronizujte dáta so svojimi zariadeniami!",
     "Go back" : "Ísť späť",
+    "Filter file names …" : "Filtrovať názvy súborov ...",
     "Views" : "Zobrazenia",
     "Files settings" : "Nastavenia súborov",
     "Your files" : "Vaše súbory",
@@ -184,6 +192,9 @@ OC.L10N.register(
     "Copy to clipboard" : "Skopírovať do schránky",
     "Use this address to access your Files via WebDAV" : "Táto adresa sa používa na prístup k vašim súborom prostredníctvom WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Ak ste povolili 2FA, musíte kliknutím sem vytvoriť a použiť nové heslo pre aplikáciu.",
+    "Warnings" : "Upozornenia",
+    "Prevent warning dialogs from open or reenable them." : "Zabrániť otváraniu varovných dialógov alebo ich znova povoliť.",
+    "Show a warning dialog when changing a file extension." : "Pri zmene prípony súboru zobraziť dialógové okno s upozornením.",
     "Keyboard shortcuts" : "Klávesové skratky",
     "Speed up your Files experience with these quick shortcuts." : "Zrýchlite používanie Súborov využitím klávesových skratiek.",
     "Open the actions menu for a file" : "Otvoriť menu akcií pre súbor",
@@ -220,11 +231,15 @@ OC.L10N.register(
     "Creating file" : "Vytvára sa súbor",
     "Save as {displayName}" : "Uložiť ako {displayName}",
     "Save as …" : "Uložiť ako ...",
+    "Converting files …" : "Konverzia súborov ...",
     "Failed to convert files: {message}" : "Nepodarilo sa skonvertovať súbory: {message}",
     "All files failed to be converted" : "Nepodarilo sa skonvertovať žiadne súbory",
     "One file could not be converted: {message}" : "Jeden súbor sa nepodarilo skonvertovať: {message}",
+    "_One file could not be converted_::_%n files could not be converted_" : ["Jeden súbor sa nepodarilo skonvertovať","%n súbory sa nepodarilo skonvertovať","%n súborov sa nepodarilo skonvertovať","%n súborov sa nepodarilo skonvertovať"],
+    "_One file successfully converted_::_%n files successfully converted_" : ["Jeden súbor bol úspešne skonvertovaný","%n súbory boli úspešne skonvertované","%n súborov bolo úspešne skonvertovaných","%n súborov bolo úspešne skonvertovaných"],
     "Files successfully converted" : "Súbory boli úspešne skonvertované",
     "Failed to convert files" : "Konverzia súborov zlyhala",
+    "Converting file …" : "Konverzia súborov ...",
     "File successfully converted" : "Súbor bol úspešne skonvertovaný",
     "Failed to convert file: {message}" : "Nepodarilo sa skonvertovať súbor: {message}",
     "Failed to convert file" : "Konverzia súboru zlyhala",
@@ -421,6 +436,7 @@ OC.L10N.register(
     "Upload file" : "Nahrať súbor",
     "Not favorited" : "Nie je obľúbený",
     "An error occurred while trying to update the tags" : "Pri pokuse o aktualizáciu štítkov došlo k chybe",
+    "You don't have permission to upload or create files here." : "Nemáte oprávnenie nahrávať alebo vytvárať súbory v tomto mieste.",
     "Storage informations" : "Úložiskové informácie",
     "Choose file" : "Vybrať súbor",
     "Go to the previous folder" : "Prejsť do predchádzajúceho priečinka",
