@@ -70,7 +70,7 @@ OC.L10N.register(
     "in %s" : "в %s",
     "Transferred from %1$s on %2$s" : "Перенесено від %1$s до %2$s",
     "Files compatibility" : "Сумісність файлів",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Дозволити обмежувати імена файлів для забезпечення сумісності з різними клієнтами. Типово всі імена файлів, які  відповідають моделі POSIX (напр. Linux, macOS) дозволені.",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Дозволити обмежувати імена файлів для забезпечення сумісності з різними клієнтами. Типово всі імена файлів, які  відповідають моделі POSIX (напр., Linux, macOS), дозволені.",
     "Enforce Windows compatibility" : "Увімкнути сумісність із Windows",
     "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Це унеможливить використання імен файлів, які не сумісні з системами Windows, напр., використанння зарезервованих імен або спеціальних символів. Зауважте, що це не обмежить сумісність за регістром символів.",
     "File Management" : "Керування файлами",
@@ -131,7 +131,7 @@ OC.L10N.register(
     "Fill template fields" : "Заповнити поля шаблону",
     "Submitting fields …" : "Надсилання полів ...",
     "Submit" : "Відправити",
-    "Choose a file or folder to transfer" : "Виберіть файл або каталог, права на який ви бажаєте передати",
+    "Choose a file or folder to transfer" : "Виберіть файл або каталог",
     "Transfer" : "Передати",
     "Transfer {path} to {userid}" : "Передати {path} користувачеві {userid}",
     "Invalid path selected" : "Вибрано неправильний шлях",
@@ -235,6 +235,8 @@ OC.L10N.register(
     "Failed to convert files: {message}" : "Не вдалося конвертувати файли: {message}",
     "All files failed to be converted" : "Не вдалося конвертувати жодний файл",
     "One file could not be converted: {message}" : "Неможливо конвертувати один файл: {message}",
+    "_One file could not be converted_::_%n files could not be converted_" : ["Неможливо конвертувати 1 файл","Неможливо конвертувати %n файли","Неможливо конвертувати %n файлів","Неможливо конвертувати %n файлів"],
+    "_One file successfully converted_::_%n files successfully converted_" : ["Успішно конвертовано 1 файл","Успішно конвертовано %n файли","Успішно конвертовано %n файлів","Успішно конвертовано %n файлів"],
     "Files successfully converted" : "Файли успішно конвертовано",
     "Failed to convert files" : "Не вдалося конвертувати файли",
     "Converting file …" : "Конвертування файлу ...",
@@ -279,7 +281,7 @@ OC.L10N.register(
     "Open in Files" : "Відкрити у Файлах",
     "Open file locally" : "Відкрити файл локально",
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Тепер файл можна відкрити на вашому пристрої. Якщо він не відкривається, перевірте, що у вас встановлено настільний клієнт синхронізації.",
-    "Retry and close" : "Спробувати ще раз та закрити",
+    "Retry and close" : "Спробувати ще раз",
     "Open online" : "Відкрити віддалено",
     "Failed to redirect to client" : "Не вдалося перенаправити на клієнта",
     "Open locally" : "Відкрити локально",
@@ -329,6 +331,7 @@ OC.L10N.register(
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 файл та {folderCount} каталог","1 файл та {folderCount} каталоги","1 файл та {folderCount} каталогів","1 файл та {folderCount} каталогів"],
     "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} файл та 1 каталог","{fileCount} файли та 1 каталог","{fileCount} файлів та 1 каталог","{fileCount} файлів та 1 каталог"],
     "{fileCount} files and {folderCount} folders" : "{fileCount} файлів та {folderCount} каталогів",
+    "_(%n hidden)_::_ (%n hidden)_" : ["(%n приховано)"," (%n прихованих)"," (%n прихованих)"," (%n прихованих)"],
     "Filename must not be empty." : "Імена файлів не мають бути порожні.",
     "\"{char}\" is not allowed inside a filename." : "Символ \"{char}\" не дозволено у імені файлу.",
     "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" є зарезервованим ім'ям і не дозволяється у іменах файлів.",
@@ -375,7 +378,7 @@ OC.L10N.register(
     "Error when assembling chunks, status code {status}" : "Помилка під час збірки частин, код помилки {status}",
     "Choose target folder" : "Виберіть каталог призначення",
     "Set reminder" : "Встановити нагадування",
-    "Edit locally" : "Редагувати локально",
+    "Edit locally" : "Відкрити на пристрої",
     "Open" : "Відкрити",
     "Could not load info for file \"{file}\"" : "Не вдалося отримати дані щодо файлу \"{file}\"",
     "Details" : "Деталі",
@@ -441,7 +444,7 @@ OC.L10N.register(
     "Open the files app settings" : "Перейти до налаштувань застосунку файлів",
     "Unable to change the favourite state of the file" : "Неможливо змінити стан \"зірочка\" для цього файла",
     "Edit file locally" : "Редагувати файл на пристрої",
-    "Edit online" : "Редагувати в онлайні",
+    "Edit online" : "Відкрити онлайн",
     "Create new templates folder" : "Створіть новий каталог для шаблонів",
     "List of favorites files and folders." : "Список файлів та каталогів із зірочкою.",
     "Personal Files" : "Мої документи",
