@@ -122,7 +122,7 @@ OC.L10N.register(
     "Add photos to this place" : "Fotos zu diesem Ort hinzufügen",
     "Cover photo for place {placeName}" : "Titelbild für Ort {placeName}",
     "There is no place yet!" : "Es gibt noch keinen Ort",
-    "Cover photo for shared album {albumName}." : "Titelbild für das geteilte Album {albumName}.",
+    "Cover photo for shared album {albumName}" : "Titelbild für das geteilte Album {albumName}",
     "Back to tags overview" : "Zurück zur Schlagwortübersicht",
     "No photos with this tag yet" : "Noch keine Fotos mit diesem Schlagwort",
     "No tags yet" : "Noch keine Schlagworte vorhanden",
@@ -148,12 +148,12 @@ OC.L10N.register(
     "{title}'s face" : "{title}´s Gesicht",
     "{startDate} to {endDate}" : "{startDate} bis {endDate}",
     "Details" : "Details",
-    "Failed to rename {oldName} to {faceName}." : "{oldName} konnte nicht in {faceName} umbenannt werden.",
-    "Failed to delete {faceName}." : "{faceName} konnte nicht gelöscht werden.",
-    "Failed to delete {fileId}." : "{fileId} konnte nicht gelöscht werden.",
-    "Failed to delete {fileName}." : "{fileName} konnte nicht gelöscht werden.",
-    "Failed to set favorite state for {fileId}." : "Fehler beim Festlegen des Favoritenstatus für {fileId}.",
-    "Failed to set favorite state for {fileName}." : "Fehler beim Festlegen des Favoritenstatus für {fileName}.",
+    "Failed to rename {oldName} to {faceName}" : "{oldName} konnte nicht in {faceName} umbenannt werden.",
+    "Failed to delete {faceName}" : "{faceName} konnte nicht gelöscht werden",
+    "Failed to delete {fileId}" : "{fileId} konnte nicht gelöscht werden",
+    "Failed to delete {fileName}" : "{fileName} konnte nicht gelöscht werden",
+    "Failed to set favorite state for {fileId}" : "Favoritenstatus für {fileId} konnte nicht gesetzt werden",
+    "Failed to set favorite state for {fileName}" : "Favoritenstatus für {fileName} konnte nicht gesetzt werden",
     "Could not load photos folder" : "Fotos-Ordner konnte nicht geladen werden",
     "One of the source folders does not exists" : "Einer der Quellordner existiert nicht",
     "Add" : "Hinzufügen"
