@@ -117,7 +117,6 @@ OC.L10N.register(
     "Add photos to this place" : "Lisää kuvia tälle sijainnille",
     "Cover photo for place {placeName}" : "Sijainnin {placeName} kansikuva",
     "There is no place yet!" : "Ei sijainteja!",
-    "Cover photo for shared album {albumName}." : "Kansikuva jaetulle albumille {albumName}.",
     "Back to tags overview" : "Takaisin tunnistenäkymään",
     "No photos with this tag yet" : "Ei vielä kuvia tällä tunnisteella",
     "No tags yet" : "Ei vielä tunnisteita",
@@ -141,12 +140,6 @@ OC.L10N.register(
     "{title}'s face" : "Henkilön {title} kasvot",
     "{startDate} to {endDate}" : "{startDate} - {endDate}",
     "Details" : "Tiedot",
-    "Failed to rename {oldName} to {faceName}." : "Henkilön {oldName} nimeäminen muotoon {faceName} epäonnistui.",
-    "Failed to delete {faceName}." : "Henkilön {faceName} poistaminen epäonnistui.",
-    "Failed to delete {fileId}." : "Kohteen {fileId} poistaminen epäonnistui.",
-    "Failed to delete {fileName}." : "Tiedoston {fileName} poisto epäonnistui.",
-    "Failed to set favorite state for {fileId}." : "Suosikkimääritelmän asettaminen kohteelle {fileId} epäonnistui.",
-    "Failed to set favorite state for {fileName}." : "Suosikkimääritelmän asettaminen kohteelle {fileName} epäonnistui.",
     "One of the source folders does not exists" : "Yksi lähdekansioista ei ole olemassa",
     "Add" : "Lisää"
 },
