@@ -122,7 +122,7 @@ OC.L10N.register(
     "Add photos to this place" : "新增照片至此處",
     "Cover photo for place {placeName}" : "地點 {placeName} 的封面照片",
     "There is no place yet!" : "還沒有地點！",
-    "Cover photo for shared album {albumName}." : "共享相簿 {albumName}. 的封面照片",
+    "Cover photo for shared album {albumName}" : "共享相簿 {albumName} 的封面照片",
     "Back to tags overview" : "回到標籤概覽",
     "No photos with this tag yet" : "還沒有帶有此標籤的照片",
     "No tags yet" : "尚未加入標籤",
@@ -148,12 +148,12 @@ OC.L10N.register(
     "{title}'s face" : "{title} 的臉",
     "{startDate} to {endDate}" : "{startDate} 到 {endDate}",
     "Details" : "詳細資訊",
-    "Failed to rename {oldName} to {faceName}." : "重新命名 {oldName} 為 {faceName} 失敗。",
-    "Failed to delete {faceName}." : "刪除 {faceName} 失敗。",
-    "Failed to delete {fileId}." : "刪除 {fileId} 失敗。",
-    "Failed to delete {fileName}." : "刪除 {fileName} 失敗。",
-    "Failed to set favorite state for {fileId}." : "未能為 {fileId} 設定最愛狀態。",
-    "Failed to set favorite state for {fileName}." : "未能為 {fileName} 設定最愛狀態。",
+    "Failed to rename {oldName} to {faceName}" : "無法將 {oldName} 重新命名為 {faceName}",
+    "Failed to delete {faceName}" : "刪除 {faceName} 失敗",
+    "Failed to delete {fileId}" : "刪除 {fileId} 失敗",
+    "Failed to delete {fileName}" : "刪除 {fileName} 失敗",
+    "Failed to set favorite state for {fileId}" : "無法設定 {fileId} 的收藏狀態",
+    "Failed to set favorite state for {fileName}" : "無法設定 {fileName} 的收藏狀態",
     "Could not load photos folder" : "無法載入照片資料夾",
     "One of the source folders does not exists" : "其中一個來源資料夾不存在",
     "Add" : "新增"
