@@ -31,8 +31,13 @@ OC.L10N.register(
     "Assistant results" : "助手结果",
     "Show result" : "显示结果",
     "Delete task" : "删除任务",
+    "Overwrite the file and save the current changes" : "覆盖文件并保存当前更改",
+    "Discard the current changes and load the latest version" : "放弃当前更改并加载最新版本",
     "Reload" : "重载",
+    "The file was overwritten. Your current changes cannot be auto-saved. Please choose how to proceed." : "文件已被覆盖。无法自动保存您当前的更改。请选择如何继续。",
+    "The document could not be loaded. Please check your internet connection." : "无法加载文档。请检查您的互联网连接。",
     "Reconnect" : "重新连接",
+    "You've been disconnected from the server." : "您已与服务器断开连接。",
     "This file is opened read-only as it is currently locked by {user}." : "该文件以仅读模式打开，其正被用户 {user} 锁定。",
     "Close outline view" : "关闭大纲视图",
     "Outline" : "大纲",
@@ -104,7 +109,7 @@ OC.L10N.register(
     "emoji" : "表情符号",
     "Mention someone" : "提及某人",
     "name" : "名称",
-    "Smart picker" : "Smart Picker",
+    "Smart picker" : "智能选择器",
     "something" : "某些东西",
     "Action" : "操作",
     "Undo" : "撤销",
@@ -120,7 +125,6 @@ OC.L10N.register(
     "Upload from computer" : "从电脑上传",
     "Insert from Files" : "从文件插入",
     "Formatting help" : "排版帮助",
-    "Select file or folder to link to" : "选择需要链接的文件或文件夹",
     "Link to file or folder" : "链接至文件或文件夹",
     "Link to website" : "链接至网站",
     "Update link" : "更新链接",
@@ -145,6 +149,9 @@ OC.L10N.register(
     "No command found" : "找不到任何命令",
     "No user found" : "找不到任何用户",
     "No suggestion found" : "找不到任何建议",
+    "Upload" : "上传",
+    "Insert Table" : "插入表格",
+    "Smart Picker" : "智能选择器",
     "Edit" : "编辑",
     "Copy code block" : "复制代码块",
     "Copy code" : "复制代码",
@@ -196,6 +203,7 @@ OC.L10N.register(
     "Ctrl" : "Ctrl",
     "Option" : "选项",
     "Formatting" : "格式",
+    "Select file or folder to link to" : "选择需要链接的文件或文件夹",
     "Add folder description" : "添加文件夹描述",
     "\"{name}\" already exist!" : "\"{name}\" 已存在！",
     "Created \"{name}\"" : "创建 \"{name}\"",
