@@ -31,13 +31,13 @@ OC.L10N.register(
     "Assistant results" : "小幫手結果",
     "Show result" : "顯示結果",
     "Delete task" : "刪除任務",
-    "Use current version" : "使用目前版本",
-    "Use the saved version" : "使用儲存版本",
+    "Overwrite the file and save the current changes" : "覆寫檔案並保存目前更新",
+    "Discard the current changes and load the latest version" : "放棄目前更新並載入最新版本",
     "Reload" : "重新載入",
-    "Document has been changed outside of the editor. The changes cannot be applied" : "文件已在編輯器外變更。無法套用變更。",
-    "Document could not be loaded. Please check your internet connection." : "無法載入文件。請檢查您的網路連線。",
+    "The file was overwritten. Your current changes cannot be auto-saved. Please choose how to proceed." : "檔案已被覆寫。無法自動儲存您目前的更新。請選擇要如何繼續。",
+    "The document could not be loaded. Please check your internet connection." : "無法載入文件。請檢查您的網際網路連線。",
     "Reconnect" : "重新連接",
-    "Document idle for {timeout} minutes, click to continue editing" : "文件已閒置 {timeout} 分鐘。點選以繼續編輯",
+    "You've been disconnected from the server." : "您已與伺服器斷線。",
     "This file is opened read-only as it is currently locked by {user}." : "此檔案以唯讀模式打開，因為它目前被 {user} 鎖上。",
     "Close outline view" : "關閉大綱檢視",
     "Outline" : "大綱",
@@ -125,7 +125,6 @@ OC.L10N.register(
     "Upload from computer" : "從電腦上傳",
     "Insert from Files" : "從檔案插入",
     "Formatting help" : "格式化說明",
-    "Select file or folder to link to" : "選擇要連結的檔案或資料夾",
     "Link to file or folder" : "連結至檔案或資料夾",
     "Link to website" : "連結至網站",
     "Update link" : "更新鏈接",
@@ -150,6 +149,9 @@ OC.L10N.register(
     "No command found" : "找不到命令",
     "No user found" : "找不到用戶",
     "No suggestion found" : "找不到建議",
+    "Upload" : "上傳",
+    "Insert Table" : "插入數據庫表",
+    "Smart Picker" : "智能選擇器",
     "Edit" : "編輯",
     "Copy code block" : "複製程式碼區塊",
     "Copy code" : "複製代碼",
@@ -201,6 +203,7 @@ OC.L10N.register(
     "Ctrl" : "Ctrl",
     "Option" : "選項",
     "Formatting" : "正在格式化",
+    "Select file or folder to link to" : "選擇要連結的檔案或資料夾",
     "Add folder description" : "新增資料夾描述",
     "\"{name}\" already exist!" : "「{name}」已存在！",
     "Created \"{name}\"" : "已建立「{name}」",
@@ -208,6 +211,11 @@ OC.L10N.register(
     "Could not copy to the clipboard" : "無法複製到剪貼簿",
     "Front matter" : "前言",
     "Link to this section" : "連結到本節",
+    "Use current version" : "使用目前版本",
+    "Use the saved version" : "使用儲存版本",
+    "Document has been changed outside of the editor. The changes cannot be applied" : "文件已在編輯器外變更。無法套用變更。",
+    "Document could not be loaded. Please check your internet connection." : "無法載入文件。請檢查您的網路連線。",
+    "Document idle for {timeout} minutes, click to continue editing" : "文件已閒置 {timeout} 分鐘。點選以繼續編輯",
     "Show author colors" : "顯示作者顏色",
     "Author colors are only shown until everyone has closed the document." : "僅在所有人都關閉文件前才顯示文件顏色。",
     "Detect language" : "檢測語言",
