@@ -146,8 +146,6 @@ OC.L10N.register(
     "Account name" : "Kontonavn",
     "Server side authentication failed!" : "Server side godkendelse mislykkedes!",
     "Please contact your administrator." : "Kontakt venligst din administrator.",
-    "Temporary error" : "Midlertidig fejl",
-    "Please try again." : "Prøv venligst igen.",
     "An internal error occurred." : "Der opstod en intern fejl.",
     "Please try again or contact your administrator." : "Kontakt venligst din administrator.",
     "Password" : "Adgangskode",
