@@ -146,23 +146,23 @@ OC.L10N.register(
     "Account name" : "アカウント名",
     "Server side authentication failed!" : "サーバーサイドの認証に失敗しました！",
     "Please contact your administrator." : "管理者にお問い合わせください。",
-    "Temporary error" : "一時的なエラー",
-    "Please try again." : "もう一度お試しください。",
+    "Session error" : "セッションエラー",
+    "It appears your session token has expired, please refresh the page and try again." : "セッショントークンの有効期限が切れました。ページを更新して再度お試しください。",
     "An internal error occurred." : "内部エラーが発生しました。",
     "Please try again or contact your administrator." : "もう一度やり直してみるか、管理者にお問い合わせください。",
     "Password" : "パスワード",
     "Log in with a device" : "デバイスを使ってログインする",
     "Login or email" : "ログイン名またはEメール",
     "Your account is not setup for passwordless login." : "あなたのアカウントはパスワードなしでログインできるように設定されていません。",
-    "Browser not supported" : "サポートされていないブラウザーです",
-    "Passwordless authentication is not supported in your browser." : "お使いのブラウザーはパスワードレス認証に対応していません。",
     "Your connection is not secure" : "この接続は安全ではありません",
     "Passwordless authentication is only available over a secure connection." : "パスワードレス認証は、セキュアな接続でのみ利用可能です。",
+    "Browser not supported" : "サポートされていないブラウザーです",
+    "Passwordless authentication is not supported in your browser." : "お使いのブラウザーはパスワードレス認証に対応していません。",
     "Reset password" : "パスワードをリセット",
+    "Back to login" : "ログインに戻る",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "このアカウントが存在する場合、パスワードリセットメッセージがメールアドレスに送信されています。もしメッセージが届かない場合は、メールアドレスやログイン名を確認するか、迷惑メールフォルダをチェックするか、もしくは管理者にお問い合わせください。",
     "Couldn't send reset email. Please contact your administrator." : "リセットメールを送信できませんでした。管理者に問い合わせてください。",
     "Password cannot be changed. Please contact your administrator." : "パスワードは変更できません。管理者に問い合わせてください。",
-    "Back to login" : "ログインに戻る",
     "New password" : "新しいパスワードを入力",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "ファイルが暗号化されます。パスワードがリセットされた後は、データを元に戻すことはできません。対処方法がわからない場合は、続行する前に管理者に問い合わせてください。本当に続行しますか?",
     "I know what I'm doing" : "どういう操作をしているか理解しています",
@@ -207,6 +207,42 @@ OC.L10N.register(
     "Login form is disabled." : "ログインフォームは無効です。",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud ログインフォームは無効になっています。 利用可能な場合は別のログインオプションを使用するか、管理者に問い合わせてください。",
     "More actions" : "その他のアクション",
+    "Password is too weak" : "パスワードが脆弱すぎます",
+    "Password is weak" : "パスワードが脆弱です",
+    "Password is average" : "パスワードは普通です",
+    "Password is strong" : "パスワードは強力です",
+    "Password is very strong" : "パスワードは非常に強力です",
+    "Password is extremely strong" : "パスワードは極めて強力です",
+    "Unknown password strength" : "パスワード強度が不明です",
+    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "<code>.htaccess</code>ファイルが動作していないため、おそらくあなたのデータディレクトリまたはファイルはインターネットからアクセス可能になっています。",
+    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "サーバーを適切に設定する方法については、{linkStart}ドキュメントを参照してください{linkEnd}",
+    "Autoconfig file detected" : "自動設定ファイルが検出されました",
+    "The setup form below is pre-filled with the values from the config file." : "以下のセットアップフォームには、設定ファイルの値があらかじめ入力されています。",
+    "Security warning" : "セキュリティ警告",
+    "Create administration account" : "管理アカウントを作成",
+    "Administration account name" : "管理者アカウント名",
+    "Administration account password" : "管理者アカウントパスワード",
+    "Storage & database" : "ストレージとデータベース",
+    "Data folder" : "データフォルダー",
+    "Database configuration" : "データベース設定",
+    "Only {firstAndOnlyDatabase} is available." : "{firstAndOnlyDatabase} のみ有効です。",
+    "Install and activate additional PHP modules to choose other database types." : "他のデータベースタイプを選択するためには、追加の PHP モジュールインストールして有効化してください。",
+    "For more details check out the documentation." : "詳細は、ドキュメントを確認してください。",
+    "Performance warning" : "パフォーマンス警告",
+    "You chose SQLite as database." : "あなたはSQLiteをデータベースとして選択しました。",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLiteは小規模もしくは開発用のインスタンスでのみ利用できます。プロダクション環境では他のデータベースをお勧めします。",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "ファイルの同期にクライアントを使用している場合、SQLiteの使用はお勧めできません。",
+    "Database user" : "データベースのユーザー名",
+    "Database password" : "データベースのパスワード",
+    "Database name" : "データベース名",
+    "Database tablespace" : "データベースの表領域",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "ポート番号をホスト名とともに指定してください(例：localhost：5432)。",
+    "Database host" : "データベースのホスト名",
+    "localhost" : "localhost",
+    "Installing …" : "インストールしています…",
+    "Install" : "インストール",
+    "Need help?" : "ヘルプが必要ですか？",
+    "See the documentation" : "ドキュメントを確認してください",
     "{name} version {version} and above" : "{name} バージョン {version} 以上が対象",
     "This browser is not supported" : "お使いのブラウザーはサポートされていません",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "お使いのブラウザーはサポート対象外です。新しいバージョンにアップグレードするかサポートされているブラウザーへ切り替えてください",
@@ -247,11 +283,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "入力して既存のプロジェクトを検索します",
     "New in" : "新機能",
     "View changelog" : "変更履歴を確認する",
-    "Very weak password" : "非常に弱いパスワード",
-    "Weak password" : "弱いパスワード",
-    "So-so password" : "まずまずのパスワード",
-    "Good password" : "良好なパスワード",
-    "Strong password" : "強いパスワード",
     "No action available" : "操作できません",
     "Error fetching contact actions" : "連絡先操作取得エラー",
     "Close \"{dialogTitle}\" dialog" : "\"{dialogTitle}\"ダイアログを閉じる",
@@ -289,34 +320,6 @@ OC.L10N.register(
     "File: %s" : "ファイル: %s",
     "Line: %s" : "行: %s",
     "Trace" : "トレース",
-    "Security warning" : "セキュリティ警告",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : ".htaccessファイルが動作していないため、おそらくあなたのデータディレクトリまたはファイルはインターネットからアクセス可能になっています。",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "サーバーを適正に設定する情報は、こちらの<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">ドキュメント</a>を参照してください。",
-    "<strong>Create an admin account</strong>" : "<strong>管理者アカウントを作成する</strong>",
-    "New admin account name" : "新しい管理者アカウント名",
-    "New admin password" : "新しい管理者パスワード",
-    "Show password" : "パスワードを表示",
-    "Toggle password visibility" : "パスワードの表示/非表示を切り替える",
-    "Storage & database" : "ストレージとデータベース",
-    "Data folder" : "データフォルダー",
-    "Configure the database" : "データベースを設定してください",
-    "Only %s is available." : "%s のみ有効です。",
-    "Install and activate additional PHP modules to choose other database types." : "他のデータベースタイプを選択するためには、追加の PHP モジュールインストールして有効化してください。",
-    "For more details check out the documentation." : "詳細は、ドキュメントを確認してください。",
-    "Database account" : "データベースアカウント",
-    "Database password" : "データベースのパスワード",
-    "Database name" : "データベース名",
-    "Database tablespace" : "データベースの表領域",
-    "Database host" : "データベースのホスト名",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "ポート番号をホスト名とともに指定してください(例：localhost：5432)。",
-    "Performance warning" : "パフォーマンス警告",
-    "You chose SQLite as database." : "あなたはSQLiteをデータベースとして選択しました。",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLiteは小規模もしくは開発用のインスタンスでのみ利用できます。プロダクション環境では他のデータベースをお勧めします。",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "ファイルの同期にクライアントを使用している場合、SQLiteの使用はお勧めできません。",
-    "Install" : "インストール",
-    "Installing …" : "インストールしています…",
-    "Need help?" : "ヘルプが必要ですか？",
-    "See the documentation" : "ドキュメントを確認してください",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Nextcloudを再インストールしようとしているようです。 しかし、CAN_INSTALLファイルがconfigディレクトリにありません。 続行するには、configフォルダーにCAN_INSTALLファイルを作成してください。",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "設定フォルダーからCAN_INSTALLを削除できませんでした。 このファイルを手動で削除してください。",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "このアプリケーションの動作にはJavaScriptが必要です。\n {linkstart}JavaScriptを有効にし{linkend} 、ページを更新してください。 ",
@@ -385,7 +388,22 @@ OC.L10N.register(
     "Edit Profile" : "プロフィールを編集",
     "The headline and about sections will show up here" : "見出しと概要セクションがここに表示されます",
     "Error loading message template: {error}" : "メッセージテンプレートの読み込みエラー: {error}",
+    "Very weak password" : "非常に弱いパスワード",
+    "Weak password" : "弱いパスワード",
+    "So-so password" : "まずまずのパスワード",
+    "Good password" : "良好なパスワード",
+    "Strong password" : "強いパスワード",
     "Profile not found" : "プロフィールが見つかりません",
-    "The profile does not exist." : "プロフィールはありません"
+    "The profile does not exist." : "プロフィールはありません",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : ".htaccessファイルが動作していないため、おそらくあなたのデータディレクトリまたはファイルはインターネットからアクセス可能になっています。",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "サーバーを適正に設定する情報は、こちらの<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">ドキュメント</a>を参照してください。",
+    "<strong>Create an admin account</strong>" : "<strong>管理者アカウントを作成する</strong>",
+    "New admin account name" : "新しい管理者アカウント名",
+    "New admin password" : "新しい管理者パスワード",
+    "Show password" : "パスワードを表示",
+    "Toggle password visibility" : "パスワードの表示/非表示を切り替える",
+    "Configure the database" : "データベースを設定してください",
+    "Only %s is available." : "%s のみ有効です。",
+    "Database account" : "データベースアカウント"
 },
 "nplurals=1; plural=0;");
