@@ -43,7 +43,7 @@ OC.L10N.register(
     "Wiping of device %s has started" : "S'ha començat a esborrar el dispositiu %s",
     "Wiping of device »%s« has started" : "S'ha començat a esborrar el dispositiu «%s»",
     "»%s« started remote wipe" : "«%s» ha començat a esborrar dades en remot",
-    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "El dispositiu o aplicació «%s» ha començat a esborrar les dades en remot. Rebreu un altre correu quan s'enllesteixi el procés",
+    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "El dispositiu o aplicació »%s«  ha començat a esborrar les dades en remot. Rebreu un altre correu quan s'enllesteixi el procés",
     "Wiping of device %s has finished" : "S'ha acabat d'esborrar el dispositiu %s",
     "Wiping of device »%s« has finished" : "S'ha acabat d'esborrar el dispositiu «%s»",
     "»%s« finished remote wipe" : "«%s» ha acabat d'esborrar dades en remot",
@@ -103,12 +103,12 @@ OC.L10N.register(
     "Failed to create file from template" : "No s'ha pogut crear el fitxer a partir de la plantilla",
     "Templates" : "Plantilles",
     "Storage %s cannot be moved" : "L'emmagatzematge %s no es pot moure",
-    "Moving a share (%s) into a shared folder is not allowed" : "No es permet moure una compartició (%s) a una carpeta compartida",
-    "Moving a storage (%s) into a shared folder is not allowed" : "No es permet moure un emmagatzematge (%s) a una carpeta compartida",
-    "Moving a share (%s) into another share (%s) is not allowed" : "No es permet moure una compartició (%s) a una altra compartició (%s)",
-    "Moving a share (%s) into another storage (%s) is not allowed" : "No es permet moure una compartició (%s) a un altre emmagatzematge (%s)",
-    "Moving a storage (%s) into a share (%s) is not allowed" : "No es permet moure un emmagatzematge (%s) a una compartició (%s)",
-    "Moving a storage (%s) into another storage (%s) is not allowed" : "No es permet moure un emmagatzematge (%s) a un altre emmagatzematge (%s)",
+    "Moving a share (%s) into a shared folder is not allowed" : "No és permès moure una compartició (%s) a una carpeta compartida",
+    "Moving a storage (%s) into a shared folder is not allowed" : "No és permès moure un emmagatzematge (%s) a una carpeta compartida",
+    "Moving a share (%s) into another share (%s) is not allowed" : "No és permès moure una compartició (%s) a una altra compartició (%s)",
+    "Moving a share (%s) into another storage (%s) is not allowed" : "No és permès moure una compartició (%s) a un altre emmagatzematge (%s)",
+    "Moving a storage (%s) into a share (%s) is not allowed" : "No és permès moure un emmagatzematge (%s) a una compartició (%s)",
+    "Moving a storage (%s) into another storage (%s) is not allowed" : "No és permès moure un emmagatzematge (%s) a un altre emmagatzematge (%s)",
     "Path contains invalid segments" : "El camí conté segments no vàlids",
     "Filename is a reserved word" : "El nom del fitxer és una paraula reservada",
     "Filename contains at least one invalid character" : "El nom del fitxer conté com a mínim un caràcter no vàlid",
@@ -170,13 +170,13 @@ OC.L10N.register(
     "%1$s shared %2$s with you and wants to add:" : "%1$s ha compartit %2$s amb tu i vol afegir:",
     "%1$s shared %2$s with you and wants to add" : "%1$s ha compartit %2$s amb tu i vol afegir",
     "%s added a note to a file shared with you" : "%s ha afegit una nota a un fitxer compartit amb tu",
-    "Passwords are enforced for link and mail shares" : "S'apliquen contrasenyes per compartir enllaços i correus",
+    "Passwords are enforced for link and mail shares" : "S'apliquen contrasenyes per compartició d'enllaços i correus",
     "Share recipient is not a valid user" : "El destinatari de la compartició no és un usuari vàlid",
     "Share recipient is not a valid group" : "El destinatari de la compartició no és un grup vàlid",
     "Share recipient should be empty" : "El destinatari de la compartició ha d'estar buit",
-    "Share recipient should not be empty" : "El destinatari compartit no ha d'estar buit",
-    "Share recipient is not a valid circle" : "El destinatari compartit no és un cercle vàlid",
-    "Unknown share type" : "Tipus d'element compartit desconegut",
+    "Share recipient should not be empty" : "El destinatari de la compartició no ha d'estar buit",
+    "Share recipient is not a valid circle" : "El destinatari de la compartició no és un cercle vàlid",
+    "Unknown share type" : "Tipus de compartició desconegut",
     "Share initiator must be set" : "S'ha d'establir l'iniciador de la compartició",
     "Cannot share with yourself" : "No es pot compartir amb tu mateix",
     "Shared path must be set" : "S'ha d'establir un camí compartit",
@@ -184,9 +184,9 @@ OC.L10N.register(
     "You cannot share your root folder" : "No podeu compartir la vostra carpeta arrel",
     "You are not allowed to share %s" : "No podeu compartir %s",
     "Valid permissions are required for sharing" : "Es requereixen permisos vàlids per compartir",
-    "File shares cannot have create or delete permissions" : "Els fitxers compartits no poden tenir permisos de creació o supressió",
+    "File shares cannot have create or delete permissions" : "Les comparticions de fitxers no poden tenir permisos de creació o supressió",
     "Cannot increase permissions of %s" : "No es poden augmentar els permisos de %s",
-    "Shares need at least read permissions" : "Les comparticions necessiten almenys permisos de lectura",
+    "Shares need at least read permissions" : "Les comparticions almenys necessiten permisos de lectura",
     "Files cannot be shared with delete permissions" : "No es poden compartir fitxers amb permisos de supressió",
     "Files cannot be shared with create permissions" : "No es poden compartir fitxers amb permisos de creació",
     "Expiration date is in the past" : "La data de caducitat ja ha passat",
@@ -195,23 +195,22 @@ OC.L10N.register(
     "Sharing is only allowed with group members" : "Només es permet l'ús compartit amb membres del grup",
     "Sharing %s failed, because this item is already shared with the account %s" : "No s'ha pogut compartir %s perquè l'element ja està compartit amb el compte %s",
     "Group sharing is now allowed" : "Ara es permet compartir en grup",
-    "Sharing is only allowed within your own groups" : "Només es permet compartir dins dels vostres propis grups",
+    "Sharing is only allowed within your own groups" : "La compartició només és permesa dins dels vostres propis grups",
     "Path is already shared with this group" : "El camí ja està compartit amb aquest grup",
-    "Link sharing is not allowed" : "No es permet compartir enllaços",
-    "Public upload is not allowed" : "No es permet la càrrega pública",
-    "Path contains files shared with you" : "El camí conté fitxers compartits amb tu",
+    "Link sharing is not allowed" : "La compartició d'enllaços no és permesa",
+    "Public upload is not allowed" : "La pujada pública no és permesa",
     "Sharing is disabled" : "S’ha desactivat la compartició",
     "Sharing is disabled for you" : "La compartició està desactivada per a tu",
     "Cannot share with the share owner" : "No es pot compartir amb el propietari de la compartició",
-    "Share does not have a full ID" : "La compartició no té un identificador complet",
+    "Share does not have a full ID" : "La compartició no té un ID complet",
     "Cannot change share type" : "No es pot canviar el tipus de compartició",
-    "Can only update recipient on user shares" : "Només es pot actualitzar el destinatari en els recursos compartits dels usuaris",
-    "Cannot enable sending the password by Talk with an empty password" : "No es pot activar l'enviament de la contrasenya per Parla amb una contrasenya buida",
-    "Cannot enable sending the password by Talk without setting a new password" : "No es pot activar l'enviament de la contrasenya per Parla sense establir una nova contrasenya",
-    "Cannot disable sending the password by Talk without setting a new password" : "No es pot desactivar l'enviament de la contrasenya per Parla sense establir una nova contrasenya",
-    "Share provider does not support accepting" : "El proveïdor de recursos compartits no admet l'acceptació",
-    "Cannot change target of link share" : "No es pot canviar el destí de la compartició d'enllaços",
-    "Invalid share recipient" : "El destinatari compartit no és vàlid",
+    "Can only update recipient on user shares" : "Només es pot actualitzar el destinatari en les comparticions d'usuaris",
+    "Cannot enable sending the password by Talk with an empty password" : "No es pot habilitar l'enviament de la contrasenya per Converses amb una contrasenya buida",
+    "Cannot enable sending the password by Talk without setting a new password" : "No es pot activar l'enviament de la contrasenya per Converses sense establir una nova contrasenya",
+    "Cannot disable sending the password by Talk without setting a new password" : "No es pot desactivar l'enviament de la contrasenya per Converses sense establir una nova contrasenya",
+    "Share provider does not support accepting" : "El proveïdor de la compartició no admet l'acceptació",
+    "Cannot change target of link share" : "No es pot canviar el destí de l'enllaç de compartició",
+    "Invalid share recipient" : "El destinatari de la compartició no és vàlid",
     "Group \"%s\" does not exist" : "El grup \"%s\" no existeix",
     "The requested share does not exist anymore" : "L'element compartit sol·licitat ja no existeix",
     "The requested share comes from a disabled user" : "L'element compartit sol·licitat prové d'un usuari inhabilitat",
@@ -328,7 +327,7 @@ OC.L10N.register(
     "Transcription" : "Transcripció",
     "The transcribed text" : "El text transcrit",
     "ContextAgent" : "ContextAgent",
-    "Chat with an agent" : "Xateja amb un agent",
+    "Chat with an agent" : "Xat amb un agent",
     "Chat message" : "Missatge de xat",
     "A chat message to send to the agent." : "Un missatge de xat per enviar a l'agent.",
     "Confirmation" : "Confirmació",
@@ -363,7 +362,7 @@ OC.L10N.register(
     "Output images" : "Imatges de sortida",
     "The generated images" : "Les imatges generades",
     "Free text to text prompt" : "Text lliure per indicador de text",
-    "Runs an arbitrary prompt through a language model that returns a reply" : "Executa una indicació arbitraria mitjançant un model de llenguatge que retorna una resposta",
+    "Runs an arbitrary prompt through a language model that returns a reply" : "Executa una indicació arbitraria mitjançant un model de llengua que retorna una resposta",
     "Describe a task that you want the assistant to do or ask a question" : "Descriu una tasca que vols que faci l'assistent o fes una pregunta",
     "Generated reply" : "Resposta generada",
     "The generated text from the assistant" : "El text generat per l'assistent",
@@ -381,8 +380,8 @@ OC.L10N.register(
     "The history of chat messages before the current message, starting with a message by the user" : "L'historial dels missatges de xat abans del missatge actual, començant amb un missatge de l'usuari",
     "Response message" : "Missatge de resposta",
     "The generated response as part of the conversation" : "La resposta generada com a part de la conversa",
-    "Chat with tools" : "Xatejar amb eines",
-    "Chat with the language model with tool calling support." : "Xateja amb el model d'idioma amb suport de crida d'eines.",
+    "Chat with tools" : "Xat amb eines",
+    "Chat with the language model with tool calling support." : "Xat amb el model de llengua amb suport de crida d'eines.",
     "Tool message" : "Missatge de l'eina",
     "The result of tool calls in the last interaction" : "El resultat de les crides d'eines en l'última interacció",
     "Available tools" : "Eines disponibles",
@@ -427,13 +426,13 @@ OC.L10N.register(
     "Topics" : "Temes",
     "The list of extracted topics" : "La llista de temes extrets",
     "Translate" : "Tradueix",
-    "Translate text from one language to another" : "Tradueix text d'un idioma a un altre",
+    "Translate text from one language to another" : "Tradueix text d'una llengua a un altre",
     "Origin text" : "Text d'origen",
     "The text to translate" : "El text a traduir",
     "Origin language" : "Llengua d'origen",
     "The language of the origin text" : "La llengua del text d'origen",
     "Target language" : "Llengua de destinació",
-    "The desired language to translate the origin text in" : "L'idioma desitjat per traduir el text d'origen",
+    "The desired language to translate the origin text in" : "La llengua desitjada per traduir el text d'origen",
     "Result" : "Resultat",
     "The translated text" : "Copia el text traduït",
     "Free prompt" : "Sol·licitud lliure",
@@ -455,6 +454,7 @@ OC.L10N.register(
     "Click the button below to open it." : "Feu clic en el botó següent per a obrir-ho.",
     "File is currently busy, please try again later" : "El fitxer està ocupat actualment; torneu-ho a provar més tard",
     "Cannot download file" : "No es pot baixar el fitxer",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Assegureu-vos que hi hagi un fitxer anomenat «.ocdata» en l'arrel de la carpeta de dades."
+    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Assegureu-vos que hi hagi un fitxer anomenat «.ocdata» en l'arrel de la carpeta de dades.",
+    "Path contains files shared with you" : "El camí conté fitxers compartits amb tu"
 },
 "nplurals=2; plural=(n != 1);");
