@@ -37,9 +37,9 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Folgende Plattformen werden unterstützt: %s",
     "Server version %s or higher is required." : "Server Version %s oder höher wird benötigt.",
     "Server version %s or lower is required." : "Server Version %s oder niedriger wird benötigt.",
-    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Das angemeldete Konto muss ein Administrator, ein Teil-Administrator sein oder ein Sonderrecht haben, um auf diese Einstellung zuzugreifen",
+    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Das angemeldete Konto muss ein Administrator, ein Unteradministrator sein oder ein Sonderrecht haben, um auf diese Einstellung zuzugreifen",
     "Your current IP address doesn't allow you to perform admin actions" : "Unter Ihrer aktuellen IP-Adresse sind keine Administrationsaktionen erlaubt",
-    "Logged in account must be an admin or sub admin" : "Das angemeldete Konto muss ein (Sub-)Administrator sein",
+    "Logged in account must be an admin or sub admin" : "Das angemeldete Konto muss ein (Unter-)Administrator sein",
     "Logged in account must be an admin" : "Das angemeldete Konto muss ein Administrator sein",
     "Wiping of device %s has started" : "Löschen von Gerät %s wurde gestartet",
     "Wiping of device »%s« has started" : "Löschen von Gerät »%s« wurde gestartet",
@@ -201,7 +201,6 @@ OC.L10N.register(
     "Path is already shared with this group" : "Der Pfad ist bereits mit dieser Gruppe geteilt",
     "Link sharing is not allowed" : "Freigabe via Link ist nicht erlaubt",
     "Public upload is not allowed" : "Öffentliches Hochladen ist nicht erlaubt",
-    "Path contains files shared with you" : "Der Pfad enthält für Sie freigegebene Dateien",
     "Sharing is disabled" : "Teilen ist deaktiviert",
     "Sharing is disabled for you" : "Teilen ist für Sie deaktiviert",
     "Cannot share with the share owner" : "Teilen mit dem Freigabeeigentümer nicht möglich",
@@ -457,6 +456,7 @@ OC.L10N.register(
     "Click the button below to open it." : "Klicken Sie zum Öffnen auf die untere Schaltfläche.",
     "File is currently busy, please try again later" : "Die Datei ist in Benutzung, bitte später erneut versuchen.",
     "Cannot download file" : "Datei kann nicht heruntergeladen werden",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Stellen Sie sicher, dass eine Datei \".ocdata\" im Wurzelverzeichnis des Datenverzeichnisses existiert."
+    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Stellen Sie sicher, dass eine Datei \".ocdata\" im Wurzelverzeichnis des Datenverzeichnisses existiert.",
+    "Path contains files shared with you" : "Der Pfad enthält für Sie freigegebene Dateien"
 },
 "nplurals=2; plural=(n != 1);");
