@@ -188,7 +188,6 @@ OC.L10N.register(
     "Path is already shared with this group" : "Bide-izen hau dagoeneko partekatuta dago talde honekin",
     "Link sharing is not allowed" : "Esteken partekatzea ez da onartzen",
     "Public upload is not allowed" : "Igotze publikoa ez da onartzen",
-    "Path contains files shared with you" : "Bide-izenak zurekin partekatutako fitxategiak dauzka",
     "Sharing is disabled" : "Partekatzea desgaituta dago",
     "Sharing is disabled for you" : "Partekatzea zuretzat desgaituta dago",
     "Cannot share with the share owner" : "Ezin da partekatzearen jabearekin partekatu",
@@ -444,6 +443,7 @@ OC.L10N.register(
     "Click the button below to open it." : "Egin klik beheko botoian hura irekitzeko.",
     "File is currently busy, please try again later" : "Fitxategia lanpetuta dago, saiatu berriro geroago",
     "Cannot download file" : "Ezin da fitxategia deskargatu",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Ziurtatu datu direktorioaren erroan \".ocdata\" izeneko fitxategia dagoela."
+    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Ziurtatu datu direktorioaren erroan \".ocdata\" izeneko fitxategia dagoela.",
+    "Path contains files shared with you" : "Bide-izenak zurekin partekatutako fitxategiak dauzka"
 },
 "nplurals=2; plural=(n != 1);");
