@@ -38,6 +38,7 @@ OC.L10N.register(
     "Server version %s or higher is required." : "Je vyžadovaná verzia servera %s alebo vyššia.",
     "Server version %s or lower is required." : "Je vyžadovaná verzia servera %s alebo nižšia.",
     "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Prihlásený účet musí byť správcom, podadministrátorom alebo musí mať špeciálne právo na prístup k tomuto nastaveniu.",
+    "Your current IP address doesn't allow you to perform admin actions" : "Vaša aktuálna adresa IP vám neumožňuje vykonávať akcie správcu",
     "Logged in account must be an admin or sub admin" : "Prihlásený účet musí byť správcom alebo sub správcom.",
     "Logged in account must be an admin" : "Prihlásený účet musí byť správcom",
     "Wiping of device %s has started" : "Začalo sa mazanie zariadenia %s",
@@ -155,6 +156,7 @@ OC.L10N.register(
     "Oracle connection could not be established" : "Nie je možné pripojiť sa k Oracle",
     "Oracle Login and/or password not valid" : "Prihlasovacie meno a/alebo heslo pre Oracle databázu je neplatné",
     "PostgreSQL Login and/or password not valid" : "Prihlasovacie meno a/alebo heslo pre PostgreSQL databázu je neplatné",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X nie je podporovaný a %s nebude správne fungovať na tejto platforme. Použitie na vlastné riziko!",
     "For the best results, please consider using a GNU/Linux server instead." : "Pre dosiahnutie najlepších výsledkov, prosím zvážte použitie GNU/Linux servera.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Zdá sa, že táto inštancia %s beží v 32-bitovom prostredí PHP a v php.ini bola nastavená voľba open_basedir. To bude zdrojom problémov so súbormi väčšími ako 4GB a dôrazne sa neodporúča.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Prosím, odstráňte nastavenie open_basedir vo vašom php.ini alebo prejdite na 64-bit PHP.",
@@ -199,7 +201,6 @@ OC.L10N.register(
     "Path is already shared with this group" : "Cesta je už zdieľaná s touto skupinou",
     "Link sharing is not allowed" : "Zdieľanie odkazu nie je povolené",
     "Public upload is not allowed" : "Verejné nahrávanie nie je povolené",
-    "Path contains files shared with you" : "Cesta obsahuje súbory zdieľané s vami",
     "Sharing is disabled" : "Zdieľanie je zakázané",
     "Sharing is disabled for you" : "Zdieľanie je pre vás zakázané",
     "Cannot share with the share owner" : "Nie je možné zdieľať s vlastníkom",
@@ -455,6 +456,7 @@ OC.L10N.register(
     "Click the button below to open it." : "Pre otvorenie klienta kliknite na tlačítko nižšie.",
     "File is currently busy, please try again later" : "Súbor sa práve používa, skúste prosím neskôr",
     "Cannot download file" : "Nemožno stiahnuť súbor",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Uistite sa, že v koreňovom adresári sa nachádza súbor s názvom \".ocdata\"."
+    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Uistite sa, že v koreňovom adresári sa nachádza súbor s názvom \".ocdata\".",
+    "Path contains files shared with you" : "Cesta obsahuje súbory zdieľané s vami"
 },
 "nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
