@@ -2,30 +2,15 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2022 Robin Appelman <robin@icewind.nl>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2022 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OC\Files;
 
 use OC\Files\Config\MountProviderCollection;
+use OC\Files\Mount\HomeMountPoint;
 use OC\Files\Mount\MountPoint;
-use OC\Files\ObjectStore\HomeObjectStoreStorage;
 use OC\Files\Storage\Common;
 use OC\Files\Storage\Home;
 use OC\Files\Storage\Storage;
@@ -34,15 +19,23 @@ use OC\Files\Storage\Wrapper\Encoding;
 use OC\Files\Storage\Wrapper\PermissionsMask;
 use OC\Files\Storage\Wrapper\Quota;
 use OC\Lockdown\Filesystem\NullStorage;
+use OC\Share\Share;
+use OC\Share20\ShareDisableChecker;
 use OC_App;
 use OC_Hook;
 use OC_Util;
+use OCA\Files_External\Config\ExternalMountPoint;
+use OCA\Files_Sharing\External\Mount;
+use OCA\Files_Sharing\ISharedMountPoint;
+use OCA\Files_Sharing\SharedMount;
 use OCP\Constants;
 use OCP\Diagnostics\IEventLogger;
 use OCP\EventDispatcher\IEventDispatcher;
+use OCP\Files\Config\ICachedMountInfo;
 use OCP\Files\Config\IHomeMountProvider;
 use OCP\Files\Config\IMountProvider;
 use OCP\Files\Config\IUserMountCache;
+use OCP\Files\Events\BeforeFileSystemSetupEvent;
 use OCP\Files\Events\InvalidateMountCacheEvent;
 use OCP\Files\Events\Node\FilesystemTornDownEvent;
 use OCP\Files\Mount\IMountManager;
@@ -63,52 +56,35 @@ use Psr\Log\LoggerInterface;
 
 class SetupManager {
 	private bool $rootSetup = false;
-	private IEventLogger $eventLogger;
-	private MountProviderCollection $mountProviderCollection;
-	private IMountManager $mountManager;
-	private IUserManager $userManager;
 	// List of users for which at least one mount is setup
 	private array $setupUsers = [];
 	// List of users for which all mounts are setup
 	private array $setupUsersComplete = [];
 	/** @var array<string, string[]> */
 	private array $setupUserMountProviders = [];
-	private IEventDispatcher $eventDispatcher;
-	private IUserMountCache $userMountCache;
-	private ILockdownManager $lockdownManager;
-	private IUserSession $userSession;
 	private ICache $cache;
-	private LoggerInterface $logger;
-	private IConfig $config;
 	private bool $listeningForProviders;
 	private array $fullSetupRequired = [];
 	private bool $setupBuiltinWrappersDone = false;
+	private bool $forceFullSetup = false;
 
 	public function __construct(
-		IEventLogger $eventLogger,
-		MountProviderCollection $mountProviderCollection,
-		IMountManager $mountManager,
-		IUserManager $userManager,
-		IEventDispatcher $eventDispatcher,
-		IUserMountCache $userMountCache,
-		ILockdownManager $lockdownManager,
-		IUserSession $userSession,
+		private IEventLogger $eventLogger,
+		private MountProviderCollection $mountProviderCollection,
+		private IMountManager $mountManager,
+		private IUserManager $userManager,
+		private IEventDispatcher $eventDispatcher,
+		private IUserMountCache $userMountCache,
+		private ILockdownManager $lockdownManager,
+		private IUserSession $userSession,
 		ICacheFactory $cacheFactory,
-		LoggerInterface $logger,
-		IConfig $config
+		private LoggerInterface $logger,
+		private IConfig $config,
+		private ShareDisableChecker $shareDisableChecker,
 	) {
-		$this->eventLogger = $eventLogger;
-		$this->mountProviderCollection = $mountProviderCollection;
-		$this->mountManager = $mountManager;
-		$this->userManager = $userManager;
-		$this->eventDispatcher = $eventDispatcher;
-		$this->userMountCache = $userMountCache;
-		$this->lockdownManager = $lockdownManager;
-		$this->logger = $logger;
-		$this->userSession = $userSession;
 		$this->cache = $cacheFactory->createDistributed('setupmanager::');
 		$this->listeningForProviders = false;
-		$this->config = $config;
+		$this->forceFullSetup = $this->config->getSystemValueBool('debug.force-full-fs-setup');
 
 		$this->setupListeners();
 	}
@@ -133,50 +109,55 @@ class SetupManager {
 
 		Filesystem::addStorageWrapper('mount_options', function ($mountPoint, IStorage $storage, IMountPoint $mount) {
 			if ($storage->instanceOfStorage(Common::class)) {
-				$storage->setMountOptions($mount->getOptions());
+				$options = array_merge($mount->getOptions(), ['mount_point' => $mountPoint]);
+				$storage->setMountOptions($options);
 			}
 			return $storage;
 		});
 
-		Filesystem::addStorageWrapper('enable_sharing', function ($mountPoint, IStorage $storage, IMountPoint $mount) {
-			if (!$mount->getOption('enable_sharing', true)) {
-				return new PermissionsMask([
-					'storage' => $storage,
-					'mask' => Constants::PERMISSION_ALL - Constants::PERMISSION_SHARE,
-				]);
+		$reSharingEnabled = Share::isResharingAllowed();
+		$user = $this->userSession->getUser();
+		$sharingEnabledForUser = $user ? !$this->shareDisableChecker->sharingDisabledForUser($user->getUID()) : true;
+		Filesystem::addStorageWrapper(
+			'sharing_mask',
+			function ($mountPoint, IStorage $storage, IMountPoint $mount) use ($reSharingEnabled, $sharingEnabledForUser) {
+				$sharingEnabledForMount = $mount->getOption('enable_sharing', true);
+				$isShared = $mount instanceof ISharedMountPoint;
+				if (!$sharingEnabledForMount || !$sharingEnabledForUser || (!$reSharingEnabled && $isShared)) {
+					return new PermissionsMask([
+						'storage' => $storage,
+						'mask' => Constants::PERMISSION_ALL - Constants::PERMISSION_SHARE,
+					]);
+				}
+				return $storage;
 			}
-			return $storage;
-		});
+		);
 
 		// install storage availability wrapper, before most other wrappers
-		Filesystem::addStorageWrapper('oc_availability', function ($mountPoint, IStorage $storage) {
-			if (!$storage->instanceOfStorage('\OCA\Files_Sharing\SharedStorage') && !$storage->isLocal()) {
+		Filesystem::addStorageWrapper('oc_availability', function ($mountPoint, IStorage $storage, IMountPoint $mount) {
+			$externalMount = $mount instanceof ExternalMountPoint || $mount instanceof Mount;
+			if ($externalMount && !$storage->isLocal()) {
 				return new Availability(['storage' => $storage]);
 			}
 			return $storage;
 		});
 
 		Filesystem::addStorageWrapper('oc_encoding', function ($mountPoint, IStorage $storage, IMountPoint $mount) {
-			if ($mount->getOption('encoding_compatibility', false) && !$storage->instanceOfStorage('\OCA\Files_Sharing\SharedStorage')) {
+			if ($mount->getOption('encoding_compatibility', false) && !$mount instanceof SharedMount) {
 				return new Encoding(['storage' => $storage]);
 			}
 			return $storage;
 		});
 
-		Filesystem::addStorageWrapper('oc_quota', function ($mountPoint, $storage) {
+		$quotaIncludeExternal = $this->config->getSystemValue('quota_include_external_storage', false);
+		Filesystem::addStorageWrapper('oc_quota', function ($mountPoint, $storage, IMountPoint $mount) use ($quotaIncludeExternal) {
 			// set up quota for home storages, even for other users
 			// which can happen when using sharing
-
-			/**
-			 * @var Storage $storage
-			 */
-			if ($storage->instanceOfStorage(HomeObjectStoreStorage::class) || $storage->instanceOfStorage(Home::class)) {
-				if (is_object($storage->getUser())) {
-					$user = $storage->getUser();
-					return new Quota(['storage' => $storage, 'quotaCallback' => function () use ($user) {
-						return OC_Util::getUserQuota($user);
-					}, 'root' => 'files']);
-				}
+			if ($mount instanceof HomeMountPoint) {
+				$user = $mount->getUser();
+				return new Quota(['storage' => $storage, 'quotaCallback' => function () use ($user) {
+					return OC_Util::getUserQuota($user);
+				}, 'root' => 'files', 'include_external_storage' => $quotaIncludeExternal]);
 			}
 
 			return $storage;
@@ -190,10 +171,10 @@ class SetupManager {
 				return new PermissionsMask([
 					'storage' => $storage,
 					'mask' => Constants::PERMISSION_ALL & ~(
-							Constants::PERMISSION_UPDATE |
-							Constants::PERMISSION_CREATE |
-							Constants::PERMISSION_DELETE
-						),
+						Constants::PERMISSION_UPDATE |
+						Constants::PERMISSION_CREATE |
+						Constants::PERMISSION_DELETE
+					),
 				]);
 			}
 			return $storage;
@@ -211,6 +192,8 @@ class SetupManager {
 		}
 		$this->setupUsersComplete[] = $user->getUID();
 
+		$this->eventLogger->start('fs:setup:user:full', 'Setup full filesystem for user');
+
 		if (!isset($this->setupUserMountProviders[$user->getUID()])) {
 			$this->setupUserMountProviders[$user->getUID()] = [];
 		}
@@ -219,29 +202,38 @@ class SetupManager {
 
 		$this->setupForUserWith($user, function () use ($user) {
 			$this->mountProviderCollection->addMountForUser($user, $this->mountManager, function (
-				IMountProvider $provider
+				IMountProvider $provider,
 			) use ($user) {
 				return !in_array(get_class($provider), $this->setupUserMountProviders[$user->getUID()]);
 			});
 		});
 		$this->afterUserFullySetup($user, $previouslySetupProviders);
+		$this->eventLogger->end('fs:setup:user:full');
 	}
 
 	/**
 	 * part of the user setup that is run only once per user
 	 */
 	private function oneTimeUserSetup(IUser $user) {
-		if (in_array($user->getUID(), $this->setupUsers, true)) {
+		if ($this->isSetupStarted($user)) {
 			return;
 		}
 		$this->setupUsers[] = $user->getUID();
 
+		$this->setupRoot();
+
+		$this->eventLogger->start('fs:setup:user:onetime', 'Onetime filesystem for user');
+
 		$this->setupBuiltinWrappers();
 
 		$prevLogging = Filesystem::logWarningWhenAddingStorageWrapper(false);
 
+		// TODO remove hook
 		OC_Hook::emit('OC_Filesystem', 'preSetup', ['user' => $user->getUID()]);
 
+		$event = new BeforeFileSystemSetupEvent($user);
+		$this->eventDispatcher->dispatchTyped($event);
+
 		Filesystem::logWarningWhenAddingStorageWrapper($prevLogging);
 
 		$userDir = '/' . $user->getUID() . '/files';
@@ -249,14 +241,18 @@ class SetupManager {
 		Filesystem::initInternal($userDir);
 
 		if ($this->lockdownManager->canAccessFilesystem()) {
+			$this->eventLogger->start('fs:setup:user:home', 'Setup home filesystem for user');
 			// home mounts are handled separate since we need to ensure this is mounted before we call the other mount providers
 			$homeMount = $this->mountProviderCollection->getHomeMountForUser($user);
 			$this->mountManager->addMount($homeMount);
 
 			if ($homeMount->getStorageRootId() === -1) {
+				$this->eventLogger->start('fs:setup:user:home:scan', 'Scan home filesystem for user');
 				$homeMount->getStorage()->mkdir('');
 				$homeMount->getStorage()->getScanner()->scan('');
+				$this->eventLogger->end('fs:setup:user:home:scan');
 			}
+			$this->eventLogger->end('fs:setup:user:home');
 		} else {
 			$this->mountManager->addMount(new MountPoint(
 				new NullStorage([]),
@@ -270,16 +266,19 @@ class SetupManager {
 		}
 
 		$this->listenForNewMountProviders();
+
+		$this->eventLogger->end('fs:setup:user:onetime');
 	}
 
 	/**
 	 * Final housekeeping after a user has been fully setup
 	 */
 	private function afterUserFullySetup(IUser $user, array $previouslySetupProviders): void {
+		$this->eventLogger->start('fs:setup:user:full:post', 'Housekeeping after user is setup');
 		$userRoot = '/' . $user->getUID() . '/';
 		$mounts = $this->mountManager->getAll();
 		$mounts = array_filter($mounts, function (IMountPoint $mount) use ($userRoot) {
-			return strpos($mount->getMountPoint(), $userRoot) === 0;
+			return str_starts_with($mount->getMountPoint(), $userRoot);
 		});
 		$allProviders = array_map(function (IMountProvider $provider) {
 			return get_class($provider);
@@ -295,6 +294,7 @@ class SetupManager {
 			$this->cache->set($user->getUID(), true, $cacheDuration);
 			$this->fullSetupRequired[$user->getUID()] = false;
 		}
+		$this->eventLogger->end('fs:setup:user:full:post');
 	}
 
 	/**
@@ -305,23 +305,19 @@ class SetupManager {
 	 * @throws \OC\ServerNotAvailableException
 	 */
 	private function setupForUserWith(IUser $user, callable $mountCallback): void {
-		$this->setupRoot();
-
-		if (!$this->isSetupStarted($user)) {
-			$this->oneTimeUserSetup($user);
-		}
-
-		$this->eventLogger->start('setup_fs', 'Setup filesystem');
+		$this->oneTimeUserSetup($user);
 
 		if ($this->lockdownManager->canAccessFilesystem()) {
 			$mountCallback();
 		}
+		$this->eventLogger->start('fs:setup:user:post-init-mountpoint', 'post_initMountPoints legacy hook');
 		\OC_Hook::emit('OC_Filesystem', 'post_initMountPoints', ['user' => $user->getUID()]);
+		$this->eventLogger->end('fs:setup:user:post-init-mountpoint');
 
 		$userDir = '/' . $user->getUID() . '/files';
+		$this->eventLogger->start('fs:setup:user:setup-hook', 'setup legacy hook');
 		OC_Hook::emit('OC_Filesystem', 'setup', ['user' => $user->getUID(), 'user_dir' => $userDir]);
-
-		$this->eventLogger->end('setup_fs');
+		$this->eventLogger->end('fs:setup:user:setup-hook');
 	}
 
 	/**
@@ -332,18 +328,19 @@ class SetupManager {
 		if ($this->rootSetup) {
 			return;
 		}
-		$this->rootSetup = true;
-
-		$this->eventLogger->start('setup_root_fs', 'Setup root filesystem');
 
 		$this->setupBuiltinWrappers();
 
+		$this->rootSetup = true;
+
+		$this->eventLogger->start('fs:setup:root', 'Setup root filesystem');
+
 		$rootMounts = $this->mountProviderCollection->getRootMounts();
 		foreach ($rootMounts as $rootMountProvider) {
 			$this->mountManager->addMount($rootMountProvider);
 		}
 
-		$this->eventLogger->end('setup_root_fs');
+		$this->eventLogger->end('fs:setup:root');
 	}
 
 	/**
@@ -353,7 +350,7 @@ class SetupManager {
 	 * @return IUser|null
 	 */
 	private function getUserForPath(string $path) {
-		if (strpos($path, '/__groupfolders') === 0) {
+		if (str_starts_with($path, '/__groupfolders')) {
 			return null;
 		} elseif (substr_count($path, '/') < 2) {
 			if ($user = $this->userSession->getUser()) {
@@ -361,7 +358,7 @@ class SetupManager {
 			} else {
 				return null;
 			}
-		} elseif (strpos($path, '/appdata_' . \OC_Util::getInstanceId()) === 0 || strpos($path, '/files_external/') === 0) {
+		} elseif (str_starts_with($path, '/appdata_' . \OC_Util::getInstanceId()) || str_starts_with($path, '/files_external/')) {
 			return null;
 		} else {
 			[, $userId] = explode('/', $path);
@@ -390,7 +387,7 @@ class SetupManager {
 		}
 
 		// for the user's home folder, and includes children we need everything always
-		if (rtrim($path) === "/" . $user->getUID() . "/files" && $includeChildren) {
+		if (rtrim($path) === '/' . $user->getUID() . '/files' && $includeChildren) {
 			$this->setupForUser($user);
 			return;
 		}
@@ -408,38 +405,50 @@ class SetupManager {
 			return;
 		}
 
-		if (!$this->isSetupStarted($user)) {
-			$this->oneTimeUserSetup($user);
-		}
+		$this->oneTimeUserSetup($user);
+
+		$this->eventLogger->start('fs:setup:user:path', "Setup $path filesystem for user");
+		$this->eventLogger->start('fs:setup:user:path:find', "Find mountpoint for $path");
 
 		$mounts = [];
 		if (!in_array($cachedMount->getMountProvider(), $setupProviders)) {
-			$setupProviders[] = $cachedMount->getMountProvider();
 			$currentProviders[] = $cachedMount->getMountProvider();
 			if ($cachedMount->getMountProvider()) {
+				$setupProviders[] = $cachedMount->getMountProvider();
 				$mounts = $this->mountProviderCollection->getUserMountsForProviderClasses($user, [$cachedMount->getMountProvider()]);
 			} else {
-				$this->logger->debug("mount at " . $cachedMount->getMountPoint() . " has no provider set, performing full setup");
+				$this->logger->debug('mount at ' . $cachedMount->getMountPoint() . ' has no provider set, performing full setup');
+				$this->eventLogger->end('fs:setup:user:path:find');
 				$this->setupForUser($user);
+				$this->eventLogger->end('fs:setup:user:path');
 				return;
 			}
 		}
 
 		if ($includeChildren) {
 			$subCachedMounts = $this->userMountCache->getMountsInPath($user, $path);
-			foreach ($subCachedMounts as $cachedMount) {
-				if (!in_array($cachedMount->getMountProvider(), $setupProviders)) {
-					$setupProviders[] = $cachedMount->getMountProvider();
-					$currentProviders[] = $cachedMount->getMountProvider();
-					if ($cachedMount->getMountProvider()) {
+			$this->eventLogger->end('fs:setup:user:path:find');
+
+			$needsFullSetup = array_reduce($subCachedMounts, function (bool $needsFullSetup, ICachedMountInfo $cachedMountInfo) {
+				return $needsFullSetup || $cachedMountInfo->getMountProvider() === '';
+			}, false);
+
+			if ($needsFullSetup) {
+				$this->logger->debug('mount has no provider set, performing full setup');
+				$this->setupForUser($user);
+				$this->eventLogger->end('fs:setup:user:path');
+				return;
+			} else {
+				foreach ($subCachedMounts as $cachedMount) {
+					if (!in_array($cachedMount->getMountProvider(), $setupProviders)) {
+						$currentProviders[] = $cachedMount->getMountProvider();
+						$setupProviders[] = $cachedMount->getMountProvider();
 						$mounts = array_merge($mounts, $this->mountProviderCollection->getUserMountsForProviderClasses($user, [$cachedMount->getMountProvider()]));
-					} else {
-						$this->logger->debug("mount at " . $cachedMount->getMountPoint() . " has no provider set, performing full setup");
-						$this->setupForUser($user);
-						return;
 					}
 				}
 			}
+		} else {
+			$this->eventLogger->end('fs:setup:user:path:find');
 		}
 
 		if (count($mounts)) {
@@ -450,9 +459,14 @@ class SetupManager {
 		} elseif (!$this->isSetupStarted($user)) {
 			$this->oneTimeUserSetup($user);
 		}
+		$this->eventLogger->end('fs:setup:user:path');
 	}
 
 	private function fullSetupRequired(IUser $user): bool {
+		if ($this->forceFullSetup) {
+			return true;
+		}
+
 		// we perform a "cached" setup only after having done the full setup recently
 		// this is also used to trigger a full setup after handling events that are likely
 		// to change the available mounts
@@ -482,6 +496,10 @@ class SetupManager {
 			return;
 		}
 
+		$this->eventLogger->start('fs:setup:user:providers', 'Setup filesystem for ' . implode(', ', $providers));
+
+		$this->oneTimeUserSetup($user);
+
 		// home providers are always used
 		$providers = array_filter($providers, function (string $provider) {
 			return !is_subclass_of($provider, IHomeMountProvider::class);
@@ -498,6 +516,7 @@ class SetupManager {
 			if (!$this->isSetupStarted($user)) {
 				$this->oneTimeUserSetup($user);
 			}
+			$this->eventLogger->end('fs:setup:user:providers');
 			return;
 		} else {
 			$this->setupUserMountProviders[$user->getUID()] = array_merge($setupProviders, $providers);
@@ -508,6 +527,7 @@ class SetupManager {
 		$this->setupForUserWith($user, function () use ($mounts) {
 			array_walk($mounts, [$this->mountManager, 'addMount']);
 		});
+		$this->eventLogger->end('fs:setup:user:providers');
 	}
 
 	public function tearDown() {
@@ -527,7 +547,7 @@ class SetupManager {
 		if (!$this->listeningForProviders) {
 			$this->listeningForProviders = true;
 			$this->mountProviderCollection->listen('\OC\Files\Config', 'registerMountProvider', function (
-				IMountProvider $provider
+				IMountProvider $provider,
 			) {
 				foreach ($this->setupUsers as $userId) {
 					$user = $this->userManager->get($userId);
@@ -553,7 +573,7 @@ class SetupManager {
 		$this->eventDispatcher->addListener(ShareCreatedEvent::class, function (ShareCreatedEvent $event) {
 			$this->cache->remove($event->getShare()->getSharedWith());
 		});
-		$this->eventDispatcher->addListener(InvalidateMountCacheEvent::class, function (InvalidateMountCacheEvent $event
+		$this->eventDispatcher->addListener(InvalidateMountCacheEvent::class, function (InvalidateMountCacheEvent $event,
 		) {
 			if ($user = $event->getUser()) {
 				$this->cache->remove($user->getUID());
